IF OBJECT_ID('[DashboardPackages_Largest]') IS NOT NULL DROP VIEW [DashboardPackages_Largest]
GO

CREATE VIEW [DashboardPackages_Largest]
AS
SELECT * FROM
(SELECT TOP 10 NP.[Feed_Id],
			   [Package_Name] = NP.[Package_Id],
               P.[Total_Size],
			   p.[Total_Downloads],
			   [Latest_Version] = NP.[LatestStableVersion_Text],
			   [Package_Id] = NP.[Package_Id],
			   [Group_Id] = null
  FROM (SELECT NPV.[NuGetPackageV2_Id],
               [Total_Size] = SUM(NPV.[Package_Size]),
			   [Total_Downloads] = SUM(NPV.[Download_Count])
          FROM [NuGetPackageVersionsV2] NPV
		  WITH (READUNCOMMITTED)
		 GROUP BY NPV.[NuGetPackageV2_Id]
  ) P
  INNER JOIN [NuGetPackagesV2] NP
        WITH (READUNCOMMITTED)
          ON NP.[NuGetPackageV2_Id] = P.[NuGetPackageV2_Id]
 ORDER BY P.[Total_Size] DESC) _A

UNION ALL

SELECT * FROM
(SELECT TOP 10 NP.[Feed_Id],
              [Package_Name] = CASE WHEN NP.[Scope_Name] = '' THEN NP.[Package_Name] ELSE '@' + NP.[Scope_Name] + '/' + NP.[Package_Name] END,
	          p.[Total_Size],
			   p.[Total_Downloads],
				[Latest_Version] = CONVERT(varchar(10), p.[Latest_Version]),
				[Package_Id] = NP.[Package_Name],
			   [Group_Id] = NP.[Scope_Name]
  FROM [NpmPackages] NP WITH (READUNCOMMITTED)
  INNER JOIN (SELECT NPV.[Package_Id],
               [Total_Size] = SUM(NPV.[Package_Size]),
			   [Total_Downloads] = SUM(NPV.[Download_Count]),
			   [Latest_Version] = MAX(NPV.[Version_Text])
          FROM [NpmPackageVersions] NPV
		  WITH (READUNCOMMITTED)
		 GROUP BY NPV.[Package_Id]
  ) P
  ON p.Package_Id = NP.Package_Id
 ORDER BY [Total_Size] DESC) _B

UNION ALL

SELECT * FROM
(SELECT TOP 10 MA.[Feed_Id],
              [Package_Name] = MA.[GroupId_Text] + ':' + MA.[ArtifactId_Text],
			  P.[Total_Size],
			  P.[Total_Downloads],
			  [Latest_Version] = MA.[LatestVersion_Text],
			  [Package_Id] = MA.[ArtifactId_Text],
			  [Group_Id] = MA.[GroupId_Text]
  FROM [MavenArtifacts] MA WITH (READUNCOMMITTED)
  INNER JOIN (SELECT MAV.[MavenArtifact_Id],
               [Total_Size] = SUM(MAV.[File_Size]),
			   [Total_Downloads] = SUM(MAV.[Download_Count])
          FROM [MavenArtifactFiles] MAV
		  WITH (READUNCOMMITTED)
		 GROUP BY MAV.[MavenArtifact_Id]
  ) P
  ON p.[MavenArtifact_Id] = MA.[MavenArtifact_Id]
 
 ORDER BY [Total_Size] DESC) _C

UNION ALL

SELECT * FROM
(SELECT TOP 10 PGP.[Feed_Id],
              [Package_Name] = COALESCE(NULLIF(PGP.[Group_Name] + ':', ':'), '') + PGP.[Package_Name],
			  p.[Total_Size],
			  p.[Total_Downloads],
			  [Latest_Version] = PGP.[LatestVersion_Text],
			  [Package_Id] = PGP.[Package_Name],
			  [Group_Id] = PGP.[Group_Name]
  FROM [ProGetPackages] PGP WITH (READUNCOMMITTED)
  INNER JOIN (SELECT PGPV.[ProGetPackage_Id],
					[Total_Size] = SUM(PGPV.[Package_Size]),
					[Total_Downloads] = SUM(PGPV.[Download_Count])
				FROM [ProGetPackageVersions] PGPV WITH (READUNCOMMITTED)					   
				GROUP BY PGPV.[ProGetPackage_Id]
			) P
			ON p.[ProGetPackage_Id] = PGP.[ProGetPackage_Id]
 ORDER BY [Total_Size] DESC) _D

UNION ALL

SELECT * FROM
(SELECT TOP 10 RG.[Feed_Id],
              [Package_Name] = RG.[Gem_Name],
			  p.[Total_Size],
			   p.[Total_Downloads],
			   [Latest_Version] = RG.[LatestVersion_Text],
			   [Package_Id] = RG.[Gem_Name],
			   [Group_Id] = null
  FROM [RubyGems] RG WITH (READUNCOMMITTED)
  INNER JOIN (SELECT RGV.[Gem_Id],
					[Total_Size] = SUM(RGV.[Gem_Size]),
					[Total_Downloads] = SUM(RGV.[Download_Count])
				FROM [RubyGemVersions] RGV WITH (READUNCOMMITTED)					   
				GROUP BY RGV.[Gem_Id]
			) P
			ON p.[Gem_Id] = RG.[Gem_Id]
 ORDER BY [Total_Size] DESC) _E

 UNION ALL

SELECT * FROM
(SELECT TOP 10 *
  FROM (SELECT VP.[Feed_Id],
               [Package_Name] = VP.[Package_Id],
             [Total_Size] = SUM(VP.[Package_Size]),
             [Total_Downloads] = SUM(VP.[Download_Count]),
			 [Latest_Version] = MAX(CONVERT(VARCHAR(10), VP.[Major_Number]) + '.' + CONVERT(VARCHAR(10), VP.[Minor_Number]) + '.' + CONVERT(VARCHAR(10), VP.[Build_Number]) + '.' + CONVERT(VARCHAR(10), VP.[Revision_Number])),
			 [Package_Id] = VP.[Package_Id],
			 [Group_Id] = NULL
          FROM [VsixPackages] VP
      WITH (READUNCOMMITTED)
         GROUP BY [Feed_Id], [Package_Id]) P
 ORDER BY P.[Total_Size] DESC) _F

 UNION ALL

SELECT * FROM
(SELECT TOP 10 *
  FROM (SELECT DP.[Feed_Id],
               [Package_Name] = DP.[Package_Name],
             [Total_Size] = SUM(DP.[Package_Size]),
             [Total_Downloads] = SUM(DP.[Download_Count]),
			 [Latest_Version] = MAX(DP.[Version_Text]),
			 [Package_Id] = DP.[Package_Name],
			 [Group_Id] = NULL
          FROM [DebianPackages] DP
      WITH (READUNCOMMITTED)
         GROUP BY [Feed_Id], [Package_Name]) P
 ORDER BY P.[Total_Size] DESC) _G

  UNION ALL

SELECT * FROM
(SELECT TOP 10 *
  FROM (SELECT PP.[Feed_Id],
               [Package_Name] = PP.[Package_Name],
             [Total_Size] = SUM(PP.[Package_Size]),
             [Total_Downloads] = SUM(PP.[Download_Count]),
			 [Latest_Version] = MAX(PP.[Version_Text]),
			 [Package_Id] = PP.[Package_Name],
			 [Group_Id] = NULL
          FROM [PypiPackages] PP
      WITH (READUNCOMMITTED)
         GROUP BY [Feed_Id], [Package_Name]) P
 ORDER BY P.[Total_Size] DESC) _H

 UNION ALL

SELECT * FROM
(SELECT TOP 10 *
  FROM (SELECT HC.[Feed_Id],
               [Package_Name] = HC.[Chart_Name],
               [Total_Size] = SUM(HC.[Chart_Size]),
             [Total_Downloads] = SUM(HC.[Download_Count]),
			 [Latest_Version] = MAX(HC.[Version_Text]),
			 [Package_Id] = HC.[Chart_Name],
			 [Group_Id] = NULL
          FROM [HelmCharts] HC
      WITH (READUNCOMMITTED)
         GROUP BY [Feed_Id], [Chart_Name]) P
 ORDER BY P.[Total_Size] DESC) _F

 UNION ALL

SELECT * FROM
(SELECT TOP 10 *
  FROM (SELECT RP.[Feed_Id],
               [Package_Name] = RP.[Package_Name],
               [Total_Size] = SUM(RPV.[Package_Size]),
             [Total_Downloads] = SUM(RPV.[Download_Count]),
			 [Latest_Version] = MAX(RPV.[UniqueVersion_Text]) COLLATE SQL_Latin1_General_CP1_CI_AS,
			 [Package_Id] = RP.[Package_Name],
			 [Group_Id] = NULL
          FROM [RpmPackageVersions] RPV
               WITH (READUNCOMMITTED)
		       INNER JOIN [RpmPackages] RP
			         WITH (READUNCOMMITTED)
			           ON RP.[RpmPackage_Id] = RPV.[RpmPackage_Id]
         GROUP BY RP.[Feed_Id], RP.[Package_Name] COLLATE Latin1_General_CS_AS) P
 ORDER BY P.[Total_Size] DESC) _G

GO