EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'ClusterNodes_CheckPrimary',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Primary_Indicator',
    /* Description_Text        */ 'Checks if the specified node should be the primary node.'
GO

IF OBJECT_ID('[ClusterNodes_CheckPrimary]') IS NOT NULL
	DROP PROCEDURE [ClusterNodes_CheckPrimary]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ClusterNodes_CheckPrimary]
(
	@Server_Name NVARCHAR(64),
	@NodeType_Code CHAR(1),
	@FailOver_Minutes INT,
	@Primary_Indicator YNINDICATOR = NULL OUT
)
AS
BEGIN
SET NOCOUNT ON

--Default to 'N', do check for 'Y' later.
SET @Primary_Indicator = 'N'

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Now DATETIME
	SET @Now = GETUTCDATE()

	DECLARE @Primary_Server_Name NVARCHAR(64),
	        @LastUpdated_Date DATETIME

	-- find the primary node (hopefully, just one) while locking the whole table
	SELECT TOP 1 
	       @Primary_Server_Name = [Server_Name],
	       @LastUpdated_Date = [LastUpdated_Date]
	  FROM [ClusterNodes] (TABLOCKX)
	 WHERE [Primary_Indicator] = 'Y'
	   AND [NodeType_Code] = @NodeType_Code

	-- no primaries or a stale primary, become the new primary
	IF @LastUpdated_Date IS NULL OR @LastUpdated_Date < DATEADD(MINUTE, @FailOver_Minutes * -1, @Now) BEGIN
		
		 -- in the strange, off chance there is no node, add it now
		IF NOT EXISTS(SELECT * FROM [ClusterNodes] WHERE [Server_Name] = @Server_Name AND [NodeType_Code] = @NodeType_Code) BEGIN
			INSERT INTO [ClusterNodes] ([Server_Name], [NodeType_Code], [LastUpdated_Date], [Node_Configuration], [Primary_Indicator])
			VALUES (@Server_Name, @NodeType_Code, @Now, '<null />', 'Y')
		END

		SET @Primary_Server_Name = @Server_Name
	END 

	-- set the primary as needed and update current server date
	 UPDATE [ClusterNodes]
		SET [Primary_Indicator] = CASE WHEN [Server_Name] = @Primary_Server_Name THEN 'Y' ELSE 'N' END,
		    [LastUpdated_Date] = CASE WHEN [Server_Name] = @Server_Name THEN @Now ELSE [LastUpdated_Date] END
	  WHERE [NodeType_Code] = @NodeType_Code


	IF @Primary_Server_Name = @Server_Name 
		SET @Primary_Indicator = 'Y'

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [ClusterNodes_CheckPrimary] TO [ProGetUser_Role]
GO
