EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'LogMessages_AddMessage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ NULL,
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Writes a message to the error log.'
GO

IF OBJECT_ID('[LogMessages_AddMessage]') IS NOT NULL DROP PROCEDURE [LogMessages_AddMessage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [LogMessages_AddMessage]
(
	@Message_Text NVARCHAR(MAX),
    @Category_Name VARCHAR(30),
	@Message_Level INT,
	@Details_Bytes VARBINARY(MAX) = NULL,
	@Feed_Id INT = NULL,
	@Connector_Id INT = NULL
) AS
BEGIN

SET NOCOUNT ON

BEGIN TRY

	INSERT INTO [LogMessages]
	(
		[Read_Indicator],
		[Logged_Date],
		[Message_Text],
		[Category_Name],
		[Message_Level],
		[Details_Bytes],
		[Feed_Id],
		[Connector_Id]
	)
	VALUES
	(
		'N',
		GETUTCDATE(),
		@Message_Text,
		@Category_Name,
		@Message_Level,
		@Details_Bytes,
		@Feed_Id,
		@Connector_Id
	);

	WITH LM AS (
		SELECT RN = ROW_NUMBER() OVER (PARTITION BY [Message_Level]
		                                   ORDER BY [LogMessage_Id] DESC)
		  FROM [LogMessages]
	)
	DELETE
	  FROM LM
	 WHERE RN > 1000

END TRY BEGIN CATCH
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [LogMessages_AddMessage] TO [ProGetUser_Role]